.. include:: README.rst

.. toctree::
   :maxdepth: 1

   README
   source/installation
   source/user_guide
   source/lco_cr_dataset
   source/developer_guide
   source/contributing
   source/history
   source/troubleshooting
